"""
:authors: Superior_6564
:license: Apache License, Version 2.0, see LICENSE file
:copyright: (c) 2022 Superior_6564
"""
# info_txt = requests.get('https://raw.githubusercontent.com/Superior-GitHub/superior6564/main/superior6564/info.txt')
# out_1 = open("info.txt", "wb")
# out_1.write(info_txt.content)
# out_1.close()
# with open('info.txt') as f:
#     sum_letters = ""
#     version = []
#     while sum_letters != "Version":
#         line = f.readline()
#         if len(line) >= 7:
#             sum_letters = ""
#             for i in range(7):
#                 sum_letters += line[i]
#                 if sum_letters == "Version":
#                     for j in range(5):
#                         version.append(line[j + 22])

__author__ = 'Superior_6564'
# __version__ = version[0] + version[1] + version[2] + version[3] + version[4]
# __version__ = version
__email__ = 'vip.klochayil@gmail.com'
